package com.steerinfo.meterwork.meterworkmonitor.mapper;

import com.steerinfo.framework.mapper.IBaseMapper;
import com.steerinfo.meterwork.meterworkmonitor.model.MeterWorkMonitor;
import io.micrometer.core.instrument.Meter;
import org.apache.ibatis.annotations.Mapper;

import java.util.HashMap;
import java.util.List;

@Mapper
public interface MeterWorkMonitorMapper extends IBaseMapper<MeterWorkMonitor, String> {
    List<MeterWorkMonitor> selectForAss();

    int updateByPrimaryKeyNotUserNo(MeterWorkMonitor t);

    List<MeterWorkMonitor> selectNotOnLine();

    int batchUpdateForNotOnLine();

    int batchUpdateSelective(List<MeterWorkMonitor> list);

    int UpdateUserNo(List<MeterWorkMonitor> list);

    List<MeterWorkMonitor> weightByCarNo(HashMap<String, Object> map);
    List<MeterWorkMonitor> monitorLeftJoinUserSpotConfig(HashMap<String, Object> map);

    List<MeterWorkMonitor> selectForList();

}